Module: EasyTalk::Schema::ClassMethods

Includes:
EasyTalk::SchemaBase::ClassMethods
Defined in:
lib/easy_talk/schema.rb

Overview

Class methods for schema-only models.

Instance Method Summary collapse

Instance Method Details

#additional_properties_allowed?Boolean Originally defined in module EasyTalk::SchemaBase::ClassMethods

Returns:

#define_schemaObject Originally defined in module EasyTalk::SchemaBase::ClassMethods

Raises:

#json_schemaHash Originally defined in module EasyTalk::SchemaMethods

Returns the JSON schema for the model. This is the final output that includes the $schema keyword if configured.

Returns:

  • The JSON schema for the model.

#propertiesObject Originally defined in module EasyTalk::SchemaBase::ClassMethods

#ref_templateString Originally defined in module EasyTalk::SchemaMethods

Returns the reference template for the model. When prefer_external_refs is enabled and the model has a schema ID, returns the external $id URI. Otherwise, returns the local $defs reference.

Returns:

  • The reference template for the model.

#schemaObject Originally defined in module EasyTalk::SchemaBase::ClassMethods

#schema_definitionObject Originally defined in module EasyTalk::SchemaBase::ClassMethods