Module: EasyTalk::Schema::ClassMethods
- Includes:
- EasyTalk::SchemaBase::ClassMethods
- Defined in:
- lib/easy_talk/schema.rb
Overview
Class methods for schema-only models.
Instance Method Summary collapse
- #additional_properties_allowed? ⇒ Boolean included from EasyTalk::SchemaBase::ClassMethods
- #define_schema ⇒ Object included from EasyTalk::SchemaBase::ClassMethods
-
#json_schema ⇒ Hash
included
from EasyTalk::SchemaMethods
Returns the JSON schema for the model.
- #properties ⇒ Object included from EasyTalk::SchemaBase::ClassMethods
-
#ref_template ⇒ String
included
from EasyTalk::SchemaMethods
Returns the reference template for the model.
- #schema ⇒ Object included from EasyTalk::SchemaBase::ClassMethods
- #schema_definition ⇒ Object included from EasyTalk::SchemaBase::ClassMethods
Instance Method Details
#additional_properties_allowed? ⇒ Boolean Originally defined in module EasyTalk::SchemaBase::ClassMethods
#define_schema ⇒ Object Originally defined in module EasyTalk::SchemaBase::ClassMethods
#json_schema ⇒ Hash Originally defined in module EasyTalk::SchemaMethods
Returns the JSON schema for the model. This is the final output that includes the $schema keyword if configured.
#properties ⇒ Object Originally defined in module EasyTalk::SchemaBase::ClassMethods
#ref_template ⇒ String Originally defined in module EasyTalk::SchemaMethods
Returns the reference template for the model. When prefer_external_refs is enabled and the model has a schema ID, returns the external $id URI. Otherwise, returns the local $defs reference.